@@ -11,8 +11,9 @@ package MIDI::ALSA;
 no strict;
 use bytes;
 # this gives a -w warning, but $VERSION.='' confuses CPAN:
-$VERSION = '1.21';
-# 20140??? 1.21 and CHanges.
+$VERSION = '1.22';
+# 20161104 1.22
+# 20161104 1.21 test.pl works with different queue ids
 # 20140416 1.20 output-ports marked WRITE so they can receive UNSUBSCRIBED
 # 20140404 1.19 CONSTS exported as advertised
 # 20130514 1.18 parse_address matches startofstring to hide alsa-lib 1.0.24 bug
@@ -733,14 +734,6 @@ not as strings, and must therefore be used without any dollar-sign e.g.:
 
  if ($event[0] == MIDI::ALSA::SND_SEQ_EVENT_PORT_UNSUBSCRIBED) { ...
 
-Note that if the event is of type SND_SEQ_EVENT_PORT_SUBSCRIBED
-or SND_SEQ_EVENT_PORT_UNSUBSCRIBED,
-then that message has come from the System,
-and its I<dest_port> tells you which of your ports is involved.
-But its I<src_client> and I<src_port> do not tell you which other client
-disconnected;  you'll need to use I<listconnectedfrom()>
-or I<listconnectedto()> to see what's happened.
-
 The data array is mostly as documented in
 http://alsa-project.org/alsa-doc/alsa-lib/seq.html.
 For NOTE events,  the elements are
@@ -754,12 +747,24 @@ For most other events,  the elements are
 
 The I<channel> element is always 0..15
 
+In the SND_SEQ_EVENT_PITCHBEND event
+the I<value> element is from -8192..+8191 (not 0..16383)
+
+If a connection terminates, then input() returns,
+and the next event will be of type SND_SEQ_EVENT_PORT_UNSUBSCRIBED
+
+Note that if the event is of type SND_SEQ_EVENT_PORT_SUBSCRIBED
+or SND_SEQ_EVENT_PORT_UNSUBSCRIBED,
+then that message has come from the System,
+and its I<dest_port> tells you which of your ports is involved.
+But its I<src_client> and I<src_port> do not tell you which other client
+disconnected;  you'll need to use I<listconnectedfrom()>
+or I<listconnectedto()> to see what's happened.
+
 =item inputpending()
 
 Return the number of bytes available in input buffer.
 Use before input()  to wait till an event is ready to be read. 
-If a connection terminates, then inputpending() returns,
-and the next event will be of type SND_SEQ_EVENT_PORT_UNSUBSCRIBED
 
 =item output($type,$flags,$tag,$queue,$time,\@source,\@destination,\@data)
 
@@ -1011,6 +1016,80 @@ SND_SEQ_EVENT_USR_VAR0 SND_SEQ_EVENT_USR_VAR1 SND_SEQ_EVENT_USR_VAR2
 SND_SEQ_EVENT_USR_VAR3 SND_SEQ_EVENT_USR_VAR4 SND_SEQ_QUEUE_DIRECT
 SND_SEQ_TIME_STAMP_REAL VERSION
 
+You should avoid hard-coding their numerical values into your programs;
+but you may sometimes want to inspect MIDI-ALSA data eg. with Data::Dumper.
+So, sorted by number as gleaned from the source:
+
+   0     SND_SEQ_EVENT_SYSTEM
+   1     SND_SEQ_EVENT_RESULT
+
+   5     SND_SEQ_EVENT_NOTE
+   6     SND_SEQ_EVENT_NOTEON
+   7     SND_SEQ_EVENT_NOTEOFF
+   8     SND_SEQ_EVENT_KEYPRESS
+
+  10     SND_SEQ_EVENT_CONTROLLER
+  11     SND_SEQ_EVENT_PGMCHANGE
+  12     SND_SEQ_EVENT_CHANPRESS
+  13     SND_SEQ_EVENT_PITCHBEND
+  14     SND_SEQ_EVENT_CONTROL14
+  15     SND_SEQ_EVENT_NONREGPARAM
+  16     SND_SEQ_EVENT_REGPARAM
+
+  20     SND_SEQ_EVENT_SONGPOS
+  21     SND_SEQ_EVENT_SONGSEL
+  22     SND_SEQ_EVENT_QFRAME
+  23     SND_SEQ_EVENT_TIMESIGN
+  24     SND_SEQ_EVENT_KEYSIGN
+
+  30     SND_SEQ_EVENT_START
+  31     SND_SEQ_EVENT_CONTINUE
+  32     SND_SEQ_EVENT_STOP
+  33     SND_SEQ_EVENT_SETPOS_TICK
+  34     SND_SEQ_EVENT_SETPOS_TIME
+  35     SND_SEQ_EVENT_TEMPO
+  36     SND_SEQ_EVENT_CLOCK
+  37     SND_SEQ_EVENT_TICK
+  38     SND_SEQ_EVENT_QUEUE_SKEW
+  39     SND_SEQ_EVENT_SYNC_POS
+   
+  40     SND_SEQ_EVENT_TUNE_REQUEST
+  41     SND_SEQ_EVENT_RESET
+  42     SND_SEQ_EVENT_SENSING
+   
+  50     SND_SEQ_EVENT_ECHO
+  51     SND_SEQ_EVENT_OSS
+  
+  60     SND_SEQ_EVENT_CLIENT_START
+  61     SND_SEQ_EVENT_CLIENT_EXIT
+  62     SND_SEQ_EVENT_CLIENT_CHANGE
+  63     SND_SEQ_EVENT_PORT_START
+  64     SND_SEQ_EVENT_PORT_EXIT
+  65     SND_SEQ_EVENT_PORT_CHANGE
+  66     SND_SEQ_EVENT_PORT_SUBSCRIBED
+  67     SND_SEQ_EVENT_PORT_UNSUBSCRIBED
+  
+  90     SND_SEQ_EVENT_USR0
+  91     SND_SEQ_EVENT_USR1
+  92     SND_SEQ_EVENT_USR2
+  93     SND_SEQ_EVENT_USR3
+  94     SND_SEQ_EVENT_USR4
+  95     SND_SEQ_EVENT_USR5
+  96     SND_SEQ_EVENT_USR6
+  97     SND_SEQ_EVENT_USR7
+  98     SND_SEQ_EVENT_USR8
+  99     SND_SEQ_EVENT_USR9
+
+ 130     SND_SEQ_EVENT_SYSEX
+ 131     SND_SEQ_EVENT_BOUNCE
+ 135     SND_SEQ_EVENT_USR_VAR0
+ 136     SND_SEQ_EVENT_USR_VAR1
+ 137     SND_SEQ_EVENT_USR_VAR2
+ 138     SND_SEQ_EVENT_USR_VAR3
+ 139     SND_SEQ_EVENT_USR_VAR4
+   
+ 255     SND_SEQ_EVENT_NONE
+
 The MIDI standard specifies that a NOTEON event with velocity=0 means
 the same as a NOTEOFF event; so you may find a little subroutine like
 this convenient:
